@@ -4,12 +4,18 @@ use warnings;
 use base qw(XML::RSS::Headline);
 use URI::Escape qw(uri_unescape);
 
-our $VERSION = 2.1;
-
 =head1 NAME
 
 XML::RSS::Headline::Fark - XML::RSS::Headline Example Subclass
 
+=head1 VERSION
+
+2.2
+
+=cut
+
+our $VERSION = 2.2;
+
 =head1 SYNOPSIS
 
 Strip out the extra Fark redirect URL and strip out the various [blahblah]
@@ -54,32 +60,78 @@ Init the object for a parsed RSS item returned by L<XML::RSS>.
 =cut 
 
 sub item {
-    my ($self,$item) = @_;
-    $self->SUPER::item($item); # set url and description
+    my ( $self, $item ) = @_;
+    $self->SUPER::item($item);    # set url and description
 
     my $headline = $self->headline;
     $headline =~ s/\[.+?\]\s+//;
     $self->headline($headline);
 
-    my $url = $self->url;
-    my $stripit = qr/http\:\/\/go\.fark\.com\/cgi\/fark\/go\.pl\?IDLink\=\d+\&location\=/;
+    my $url     = $self->url;
+    my $stripit = qr/
+        http\:\/\/
+        go\.fark\.com\/
+        cgi\/fark\/go\.pl\?
+        IDLink\=\d+\&
+        location\=
+    /x;
+
     $url =~ s/$stripit//;
-    $self->url(uri_unescape($url));
+    $self->url( uri_unescape($url) );
 }
 
 =head1 AUTHOR
 
-Copyright 2004 Jeff Bisbee <jbisbee@cpan.org>
+Jeff Bisbee, C<< <jbisbee at cpan.org> >>
 
-http://search.cpan.org/~jbisbee/
+=head1 BUGS
 
-=head1 COPYRIGHT
+Please report any bugs or feature requests to
+C<bug-xml-rss-feed at rt.cpan.org>, or through the web interface at
+L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=XML-RSS-Feed>.
+I will be notified, and then you'll automatically be notified of progress on
+your bug as I make changes.
 
-This program is free software; you can redistribute it and/or modify it under 
-the same terms as Perl itself.
+=head1 SUPPORT
 
-The full text of the license can be found in the LICENSE file included with 
-this module.
+You can find documentation for this module with the perldoc command.
+
+    perldoc XML::RSS::Headline::Fark
+
+You can also look for information at:
+
+=over 4
+
+=item * AnnoCPAN: Annotated CPAN documentation
+
+L<http://annocpan.org/dist/XML-RSS-Feed>
+
+=item * CPAN Ratings
+
+L<http://cpanratings.perl.org/d/XML-RSS-Feed>
+
+=item * RT: CPAN's request tracker
+
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=XML-RSS-Feed>
+
+=item * Search CPAN
+
+L<http://search.cpan.org/dist/XML-RSS-Feed>
+
+=back
+
+=head1 ACKNOWLEDGEMENTS
+
+Special thanks to Rocco Caputo, Martijn van Beers, Sean Burke, Prakash Kailasa
+and Randal Schwartz for their help, guidance, patience, and bug reports. Guys 
+thanks for actually taking time to use the code and give good, honest feedback.
+
+=head1 COPYRIGHT & LICENSE
+
+Copyright 2006 Jeff Bisbee, all rights reserved.
+
+This program is free software; you can redistribute it and/or modify it
+under the same terms as Perl itself.
 
 =head1 SEE ALSO
 
